@@ -174,6 +174,8 @@
 #define GOT_ERR_BAD_TAG_SIGNATURE 154
 #define GOT_ERR_VERIFY_TAG_SIGNATURE 155
 #define GOT_ERR_SIGNING_TAG	156
+#define GOT_ERR_COMMIT_REDUNDANT_AUTHOR 157
+#define GOT_ERR_BAD_QUERYSTRING	158
 
 struct got_error {
         int code;
@@ -267,7 +269,8 @@ const struct got_error *got_error_path(const char *, int);
  * from the provided format string and the variable-length list of
  * additional arguments.
 */
-const struct got_error *got_error_fmt(int, const char *, ...);
+const struct got_error *got_error_fmt(int, const char *, ...)
+	__attribute__((__format__ (printf, 2, 3)));
 
 /*
  * Check whether open(2) with O_NOFOLLOW failed on a symlink.
