@@ -225,7 +225,7 @@ output_unidiff_chunk(struct diff_output_info *outinfo, FILE *dest,
 		     const struct diff_input_info *info,
 		     const struct diff_result *result,
 		     bool print_header, bool show_function_prototypes,
-		     const struct diff_chunk_context *cc)
+		     const struct diff_chunk_context *cc, unsigned int ncontext)
 {
 	int rc, left_start, left_len, right_start, right_len;
 	off_t outoff = 0, *offp;
@@ -292,7 +292,7 @@ output_unidiff_chunk(struct diff_output_info *outinfo, FILE *dest,
 	if (show_function_prototypes) {
 		rc = diff_output_match_function_prototype(state->prototype,
 		    sizeof(state->prototype), &state->last_prototype_idx,
-		    result, cc);
+		    result, cc, ncontext);
 		if (rc)
 			return rc;
 	}
@@ -416,7 +416,7 @@ diff_output_unidiff_chunk(struct diff_output_info **output_info, FILE *dest,
 	}
 
 	return output_unidiff_chunk(outinfo, dest, state, info,
-	    result, false, show_function_prototypes, cc);
+	    result, false, show_function_prototypes, cc, 0);
 }
 
 int
@@ -569,7 +569,7 @@ diff_output_unidiff(struct diff_output_info **output_info,
 		      " print left %d-%d right %d-%d\n",
 		      cc.left.start, cc.left.end, cc.right.start, cc.right.end);
 		output_unidiff_chunk(outinfo, dest, state, info, result,
-		    true, show_function_prototypes, &cc);
+		    true, show_function_prototypes, &cc, context_lines);
 		cc = next;
 		debug("new unprinted chunk is left %d-%d right %d-%d\n",
 		      cc.left.start, cc.left.end, cc.right.start, cc.right.end);
@@ -577,7 +577,7 @@ diff_output_unidiff(struct diff_output_info **output_info,
 
 	if (!diff_chunk_context_empty(&cc))
 		output_unidiff_chunk(outinfo, dest, state, info, result,
-		    true, show_function_prototypes, &cc);
+		    true, show_function_prototypes, &cc, context_lines);
 	diff_output_unidiff_state_free(state);
 	return DIFF_RC_OK;
 }
