@@ -15,6 +15,7 @@
  */
 
 #include <sys/time.h>
+#include <sys/queue.h>
 #include <sys/resource.h>
 
 #include <stdio.h>
@@ -226,13 +227,14 @@ got_object_cache_add(struct got_object_cache *cache, struct got_object_id *id,
 			got_object_raw_close(ce->data.raw);
 			break;
 		}
-		free(ce);
+		memset(ce, 0, sizeof(*ce));
 		cache->cache_evict++;
+	} else {
+		ce = malloc(sizeof(*ce));
+		if (ce == NULL)
+			return got_error_from_errno("malloc");
 	}
 
-	ce = malloc(sizeof(*ce));
-	if (ce == NULL)
-		return got_error_from_errno("malloc");
 	memcpy(&ce->id, id, sizeof(ce->id));
 	switch (cache->type) {
 	case GOT_OBJECT_CACHE_TYPE_OBJ:
@@ -255,6 +257,8 @@ got_object_cache_add(struct got_object_cache *cache, struct got_object_id *id,
 	err = got_object_idset_add(cache->idset, id, ce);
 	if (err)
 		free(ce);
+	else if (size > cache->max_cached_size)
+		cache->max_cached_size = size;
 	return err;
 }
 
@@ -290,13 +294,15 @@ static void
 print_cache_stats(struct got_object_cache *cache, const char *name)
 {
 	fprintf(stderr, "%s: %s cache: %d elements, %d searches, %d hits, "
-	    "%d missed, %d evicted, %d too large\n", getprogname(), name,
-	    got_object_idset_num_elements(cache->idset),
+	    "%d missed, %d evicted, %d too large, max cached %zd bytes\n",
+	    getprogname(), name,
+	    cache->idset ? got_object_idset_num_elements(cache->idset) : -1,
 	    cache->cache_searches, cache->cache_hit,
-	    cache->cache_miss, cache->cache_evict, cache->cache_toolarge);
+	    cache->cache_miss, cache->cache_evict, cache->cache_toolarge,
+	    cache->max_cached_size);
 }
 
-const struct got_error *
+static const struct got_error *
 check_refcount(struct got_object_id *id, void *data, void *arg)
 {
 	struct got_object_cache *cache = arg;
@@ -353,6 +359,35 @@ check_refcount(struct got_object_id *id, void *data, void *arg)
 }
 #endif
 
+static const struct got_error *
+free_entry(struct got_object_id *id, void *data, void *arg)
+{
+	struct got_object_cache *cache = arg;
+	struct got_object_cache_entry *ce = data;
+
+	switch (cache->type) {
+	case GOT_OBJECT_CACHE_TYPE_OBJ:
+		got_object_close(ce->data.obj);
+		break;
+	case GOT_OBJECT_CACHE_TYPE_TREE:
+		got_object_tree_close(ce->data.tree);
+		break;
+	case GOT_OBJECT_CACHE_TYPE_COMMIT:
+		got_object_commit_close(ce->data.commit);
+		break;
+	case GOT_OBJECT_CACHE_TYPE_TAG:
+		got_object_tag_close(ce->data.tag);
+		break;
+	case GOT_OBJECT_CACHE_TYPE_RAW:
+		got_object_raw_close(ce->data.raw);
+		break;
+	}
+
+	free(ce);
+
+	return NULL;
+}
+
 void
 got_object_cache_close(struct got_object_cache *cache)
 {
@@ -375,10 +410,12 @@ got_object_cache_close(struct got_object_cache *cache)
 		break;
 	}
 
-	got_object_idset_for_each(cache->idset, check_refcount, cache);
+	if (cache->idset)
+		got_object_idset_for_each(cache->idset, check_refcount, cache);
 #endif
 
 	if (cache->idset) {
+		got_object_idset_for_each(cache->idset, free_entry, cache);
 		got_object_idset_free(cache->idset);
 		cache->idset = NULL;
 	}
