@@ -16,6 +16,7 @@
 
 #include <sys/types.h>
 #include <sys/stat.h>
+#include <sys/queue.h>
 #include <sys/uio.h>
 #include <sys/socket.h>
 #include <sys/wait.h>
@@ -356,7 +357,7 @@ parse_commit_time(time_t *time, time_t *gmtoff, char *committer)
 		return got_error_from_errno("strdup");
 	err = parse_gmtoff(gmtoff, tzstr);
 	free(tzstr);
-	if (err) { 
+	if (err) {
 		if (err->code != GOT_ERR_BAD_OBJ_DATA)
 			return err;
 		/* Old versions of Git omitted the timestamp. */
