@@ -15,6 +15,7 @@
  * OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
  */
 
+#include <sys/queue.h>
 #include <sys/stat.h>
 #include <sys/time.h>
 #include <sys/types.h>
@@ -73,10 +74,10 @@ struct got_indexed_object {
 	uint64_t size;
 
 	/* Length of on-disk type+size data. */
-	size_t tslen; 
+	size_t tslen;
 
 	/* Length of object data following type+size. */
-	size_t len; 
+	size_t len;
 
 	uint32_t crc;
 
@@ -497,7 +498,7 @@ print_packidx(struct got_packidx *packidx)
 		uint32_t offset = be32toh(packidx->hdr.offsets[i]);
 		if (offset & GOT_PACKIDX_OFFSET_VAL_IS_LARGE_IDX) {
 			int j = offset & GOT_PACKIDX_OFFSET_VAL_MASK;
-			fprintf(stderr, "%u -> %llu\n", offset, 
+			fprintf(stderr, "%u -> %llu\n", offset,
 			    be64toh(packidx->hdr.large_offsets[j]));
 		} else
 			fprintf(stderr, "%u\n", offset);
@@ -903,12 +904,10 @@ index_pack(struct got_pack *pack, int idxfd, FILE *tmpfile,
 
 		}
 		if (pass++ > 3 && n == 0) {
-			static char msg[64];
-			snprintf(msg, sizeof(msg), "could not resolve "
-			    "any of deltas; packfile could be corrupt");
-			err = got_error_msg(GOT_ERR_BAD_PACKFILE, msg);
+			err = got_error_msg(GOT_ERR_BAD_PACKFILE,
+			    "could not resolve any of deltas; packfile could "
+			    "be corrupt");
 			goto done;
-
 		}
 		nresolved += n;
 		nvalid += nresolved;
