@@ -16,10 +16,12 @@
 
 #include <sys/stat.h>
 #include <sys/types.h>
+#include <sys/queue.h>
 #include <sys/uio.h>
 #include <sys/time.h>
 #include <sys/mman.h>
 
+#include <inttypes.h>
 #include <limits.h>
 #include <signal.h>
 #include <stdint.h>
@@ -849,7 +851,7 @@ get_base_object_id(struct got_object_id *base_id, struct got_packidx *packidx,
 	const struct got_error *err;
 	int idx;
 
-	err = got_packidx_get_offset_idx(&idx, packidx, base_offset); 
+	err = got_packidx_get_offset_idx(&idx, packidx, base_offset);
 	if (err)
 		return err;
 	if (idx == -1)
@@ -1662,7 +1664,8 @@ paint_commits(struct got_object_id_queue *ids, int *nids,
 		default:
 			/* should not happen */
 			err = got_error_fmt(GOT_ERR_NOT_IMPL,
-			    "%s invalid commit color %d", __func__, color);
+			    "%s invalid commit color %"PRIdPTR, __func__,
+			    color);
 			goto done;
 		}
 
@@ -1724,7 +1727,7 @@ commit_painting_free(struct got_object_idset **keep,
 		*drop = NULL;
 	}
 	if (*skip) {
-		got_object_idset_free(*skip); 
+		got_object_idset_free(*skip);
 		*skip = NULL;
 	}
 }
