@@ -16,6 +16,7 @@
  */
 
 #include <sys/types.h>
+#include <sys/queue.h>
 #include <sys/uio.h>
 #include <sys/time.h>
 #include <sys/stat.h>
@@ -116,7 +117,7 @@ recv_packfd(int *packfd, struct imsgbuf *ibuf)
 	err = got_privsep_recv_imsg(&imsg, ibuf, 0);
 	if (err)
 		return err;
-		
+
 	if (imsg.hdr.type == GOT_IMSG_STOP) {
 		err = got_error(GOT_ERR_CANCELLED);
 		goto done;
@@ -281,7 +282,7 @@ describe_refchange(int *n, int *sent_my_capabilites,
 {
 	*n = snprintf(buf, bufsize, "%s %s %s",
 	    old_hashstr, new_hashstr, refname);
-	if (*n >= bufsize)
+	if (*n < 0 || (size_t)*n >= bufsize)
 		return got_error(GOT_ERR_NO_SPACE);
 
 	/*
@@ -297,7 +298,7 @@ describe_refchange(int *n, int *sent_my_capabilites,
 			return got_error(GOT_ERR_NO_SPACE);
 		m = snprintf(buf + *n + 1, /* offset after '\0' */
 		    bufsize - (*n + 1), "%s\n", my_capabilities);
-		if (*n + m >= bufsize)
+		if (m < 0 || *n + m >= bufsize)
 			return got_error(GOT_ERR_NO_SPACE);
 		*n += m;
 		*sent_my_capabilites = 1;
@@ -386,6 +387,9 @@ send_pack(int fd, struct got_pathlist_head *refs,
 			goto done;
 
 		err = got_pathlist_append(&their_refs, refname, id);
+		if (err)
+			goto done;
+
 		if (chattygot)
 			fprintf(stderr, "%s: remote has %s %s\n",
 			    getprogname(), refname, id_str);
